from pylint.interfaces import IRawChecker
from pylint.checkers import BaseChecker

class TabChecker(BaseChecker):
    """check for any tabs as indentation"""
    
    __implements__ = IRawChecker

    name = 'tabchecker'
    msgs = {'E9901': ('Tab detected!',
                      ("Never ever use tabs for indentation!")),
            }
    options = ()

    def process_module(self, stream):
        for (lineno, line) in enumerate(stream):
            for ch in line:
                if ch == ' ':
                    pass
                elif ch == '\t':
                    self.add_message('E9901', line=lineno)
                else:
                    # only read until first non-whitespace character
                    break

def register(linter):
    """required method to auto register this checker"""
    linter.register_checker(TabChecker(linter))
 
